@@ -132,6 +132,7 @@ rast.sr <- function(x, filename = "", ...){
                                       overwrite=TRUE, filename =
                                         ifelse(mi, "", temp[3])), # ED
                            .rast.pe.B(x, inv.R, branch.length,
+                                      metric = "pe",
                                       overwrite=TRUE, filename =
                                         ifelse(mi, "", temp[4])), # PE
                            .rast.we.B(x, inv.R,
@@ -159,8 +160,8 @@ rast.sr <- function(x, filename = "", ...){
 #'
 #' @inheritParams phylo.pres
 #' @param inv.R SpatRaster. Inverse of range size. See \code{\link{inv.range}}
-#' @param edge.path matrix representing the paths through the tree from root
-#' to each tip. See \code{\link{phylo.pres}}
+#' @param edge.path matrix. Matrix representing the paths through the tree from
+#' root to each tip. See \code{\link{phylo.pres}}
 #' @param branch.length numeric. A Named numeric vector of branch length for
 #' each species. See \code{\link{phylo.pres}}
 #' @param n.descen numeric. A Named numeric vector of number of descendants for
@@ -226,6 +227,7 @@ rast.sr <- function(x, filename = "", ...){
 #' @export
 geo.phylo <- function(x, tree,
                       inv.R, edge.path, branch.length, n.descen,
+                      full_tree_metr = TRUE,
                       filename = "", ...){
 
   ## object checks
@@ -246,7 +248,7 @@ geo.phylo <- function(x, tree,
 
     } else if(any(miss4)){
 
-      data <- phylo.pres(x, tree)
+      data <- phylo.pres(x, tree, full_tree_metr = full_tree_metr)
 
       x <- data$x
       inv.R <- inv.range(x)
@@ -259,7 +261,7 @@ geo.phylo <- function(x, tree,
                   # isFALSE(identical(names(x), names(n.descen)))
                   )) {
 
-      data <- phylo.pres(x, tree)
+      data <- phylo.pres(x, tree, full_tree_metr = full_tree_metr)
 
       x <- data$x
       inv.R <- inv.range(x)
@@ -291,20 +293,25 @@ geo.phylo <- function(x, tree,
 #' @description Calculates the standardized effect size for phylogenetic
 #' community metrics. See Details for more information.
 #'
-#' @param random character. A character indicating the type of randomization.
-#' The currently available randomization methods are "tip", "site", "species" or
-#' "both" (site and species).
 #' @inheritParams geo.phylo
 #' @inheritParams SESraster::SESraster
+#' @inheritParams phylo.pres
 #'
-#' @return SpatRaster
-#'
-#' @details The spatial randomization (spat) keeps the richness exact
-#' and samples
-#' species presences proportionally to their observed frequency (i.e.
-#' number of
-#'  occupied pixels). The randomization will not assign values to cells
-#'  with nodata.
+#' @details The dependency ‘SESraster’ is used to calculate the null models.
+#' This package currently implements six algorithms to randomize binary species
+#'  distribution with several levels of constraints:
+#'  SIM1, SIM2, SIM3, SIM5, SIM6 and SIM9 (sensu Gotelli 2000).
+#'  The methods implemented in ‘SESraster’ are based on how species
+#'  (originally rows) and sites (originally columns) are treated
+#'  (i.e. fixed, equiprobable, or proportional sums) (Gotelli 2000).
+#'  By default, the ‘phyloraster’ uses the function bootspat_ str() from the
+#'  ‘SESraster’ package to conduct the randomizations, but the user is free
+#'  to choose any of the other methods mentioned above through the spat_alg
+#'  argument in the *.ses() functions of the ‘phyloraster’ package.
+#'  The bootspat_str() is equivalent to the SIM5 (proportional-fixed) method of
+#'  Gotelli (2000), which partially relaxes the spatial structure of species
+#'  distributions, but keeps the spatial structure of the observed richness
+#'  pattern across cells.
 #'
 #' @seealso \code{\link{phylo.pres}},
 #' \code{\link{inv.range}},
@@ -318,14 +325,35 @@ geo.phylo <- function(x, tree,
 #' \code{\link[SESraster]{bootspat_ff}},
 #' \code{\link[SESraster]{SESraster}}
 #'
-#' @author Neander Marcel Heming
+#' @return SpatRaster. The function returns the observed value of the metric,
+#' the mean of the simulations calculated over n times, the standard deviation
+#' of the simulations, the standardized effect size (SES) for the metric,
+#' and the p-values.
 #'
-#' @references Williams, P.H., Humphries, C.J., Forey, P.L., Humphries, C.J.,
-#' VaneWright, R.I. (1994). Biodiversity, taxonomic relatedness, and endemism
-#' in conservation. In: Systematics and Conservation Evaluation (eds Forey PL,
-#' Humphries C.J., Vane-Wright RI), p. 438. Oxford University Press, Oxford.
-#' @references Crisp, M., Laffan, S., Linder, H., Monro, A. (2001). Endemism
-#' in the Australian flora. Journal of Biogeography, 28, 183–198.
+#' @details The dependency ‘SESraster’ is used to calculate the null models.
+#' This package currently implements six algorithms to randomize binary species
+#'  distribution with several levels of constraints:
+#'  SIM1, SIM2, SIM3, SIM5, SIM6 and SIM9 (sensu Gotelli 2000).
+#'  The methods implemented in ‘SESraster’ are based on how species
+#'  (originally rows) and sites (originally columns) are treated
+#'  (i.e. fixed, equiprobable, or proportional sums) (Gotelli 2000).
+#'  By default, the ‘phyloraster’ uses the function bootspat_ str() from the
+#'  ‘SESraster’ package to conduct the randomizations, but the user is free
+#'  to choose any of the other methods mentioned above through the spat_alg
+#'  argument in the *.ses() functions of the ‘phyloraster’ package.
+#'  The bootspat_str() is equivalent to the SIM5 (proportional-fixed) method of
+#'  Gotelli (2000), which partially relaxes the spatial structure of species
+#'  distributions, but keeps the spatial structure of the observed richness
+#'  pattern across cells.
+#'
+#' @references Gotelli, N. J. 2000.
+#' Null model analysis of species co-occurrence patterns. –
+#' Ecology 81: 2606–2621.
+#' @references Heming, N. M., Mota, F. M. M. and Alves-Ferreira, G. 2023.
+#' SESraster: raster randomization for null hypothesis testing.
+#' https://CRAN.R-project.org/package=SESraster.
+#'
+#' @author Neander Marcel Heming
 #'
 #' @examples
 #' \donttest{
@@ -338,10 +366,6 @@ geo.phylo <- function(x, tree,
 #' package="phyloraster"))
 #' tses <- geo.phylo.ses(x = x,
 #'                      tree = tree,
-#'                       # FUN_args = list(range.BL=area.branch$range.BL,
-#'                       # inv.R=area.branch$inv.R,
-#'                       # branch.length=data$branch.length,
-#'                       # n.descen = data$n.descendants),
 #'                       spat_alg = "bootspat_str",
 #'                       spat_alg_args = list(rprob = NULL,
 #'                                            rich = NULL,
@@ -352,11 +376,11 @@ geo.phylo <- function(x, tree,
 #' @export
 geo.phylo.ses <- function(x, tree,
                           inv.R, edge.path, branch.length, n.descen,
+                          full_tree_metr = TRUE,
                           spat_alg = "bootspat_str",
                           spat_alg_args = list(rprob = NULL,
                                                rich = NULL,
                                                fr_prob = NULL),
-                          random = c("tip", "spat")[2],
                           aleats = 10,
                           cores = 1, filename = "", ...){
 
@@ -377,7 +401,7 @@ geo.phylo.ses <- function(x, tree,
 
     } else if(any(miss4)){
 
-      data <- phylo.pres(x, tree)
+      data <- phylo.pres(x, tree, full_tree_metr = full_tree_metr)
 
       x <- data$x
       inv.R <- inv.range(x)
@@ -390,7 +414,7 @@ geo.phylo.ses <- function(x, tree,
                   # isFALSE(identical(names(x), names(n.descen)))
                   )) {
 
-      data <- phylo.pres(x, tree)
+      data <- phylo.pres(x, tree, full_tree_metr = full_tree_metr)
 
       x <- data$x
       inv.R <- inv.range(x)
@@ -414,22 +438,6 @@ geo.phylo.ses <- function(x, tree,
                   resu = resu,
                   cores = cores)
 
-  if(random == "tip"){
-
-    ses <- SESraster::SESraster(x,
-                                FUN = ".rast.geo.phylo", FUN_args = FUN_args,
-                                Fa_sample = "branch.length",
-                                Fa_alg = "sample", Fa_alg_args =
-                                  list(replace = FALSE),
-                                spat_alg = NULL,
-                                spat_alg_args = list(),
-                                # spat_alg = spat_alg,
-                                #spat_alg_args = spat_alg_args,
-                                aleats = aleats,
-                                cores = cores, filename = filename, ...)
-
-  } else if(random == "spat"){
-
     ses <- SESraster::SESraster(x,
                                 FUN = ".rast.geo.phylo",
                                 FUN_args = FUN_args,
@@ -441,12 +449,6 @@ geo.phylo.ses <- function(x, tree,
                                 spat_alg_args = spat_alg_args,
                                 aleats = aleats,
                                 cores = cores, filename = filename, ...)
-  }  else {
-
-    stop("Choose a valid randomization method! The methods currently available
-         are: 'tip', 'spat'.")
-
-  }
   return(ses)
 
 }
