@@ -89,41 +89,29 @@ test_that("Are the returned values correct?", {
   xcrop <- terra::crop(x, terra::ext(c(150.0157, 150.8157,
                                        -23.044, -22.8563)))
 
-  pp.obs <- suppressWarnings(phylo.pres(xcrop[[1:10]], tree,
-                                        full_tree_metr = FALSE))
-  descen.expect <- c(5, 1, 1, 2, 1, 1, 1, 5, 1, 4, 1, 2, 1, 1, 1)
+  pp.obs <- suppressWarnings(phylo.pres(xcrop[[1:15]], tree,
+                                        full_tree_metr = T))
+  descen.expect <- c(0,  1,  1,  1,  1,  2,  1,  5,  1,  1,  1,  1,  1,  2,  1,
+                     4,  5, 6, 11,  1,  1,  2, 13,  1,  1,  2)
 
-  # (terra::values(pp.obs[[1]]))[,10]
-  rast.expect <- matrix(data = c(0, 0, 0, 0, 0, 0, 0, 0,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 1, 1, 1, 1, 1, 1, 1, 1,
-                                 1, 1, 0, 1, 1, 1, 1, 1,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 1, 1, 1, 1, 1, 1, 1, 1,
-                                 1, 1, 1, 1, 1, 1, 1, 1,
-                                 1, 1, 1, 1, 1, 1, 1, 1,
-                                 1, 1, 1, 1, 1, 1, 1, 1,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 1, 1, 1, 1, 1, 1, 1, 1,
-                                 1, 1, 1, 1, 1, 1, 1, 1,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 0, 0, 0, 0, 0, 0, 0, 0,
-                                 1, 1, 1, 1, 1, 1, 1, 1,
-                                 1, 1, 1, 1, 1, 1, 1, 1))
+  branch.expect <- c(0.173157, 0.072386, 0.175442, 0.589016, 0.589015, 0.193871,
+                     0.395144, 0.395144, 0.589015, 0.273621, 0.490836, 0.201929,
+                     0.288907, 0.092767, 0.196139, 0.066625, 0.129514, 0.129514,
+                     0.196139, 0.325841, 0.511002, 0.511002, 0.011052, 0.095197,
+                     0.398434, 0.020969, 0.017805, 0.466543, 0.043192, 0.423350,
+                     0.322782, 0.100568, 0.100568, 0.093810, 0.390538, 0.268077,
+                     0.122460, 0.068385, 0.054075, 0.054075, 0.251337, 0.253980,
+                     0.253980, 0.043002, 0.210977, 0.210978, 0.032253, 0.178724,
+                     0.178724, 0.154130, 0.749621, 0.401051, 0.348570, 0.348570,
+                     0.081570, 0.267000, 0.267000, 0.998948)
+
+  branch.alt.expect <- c(rep(0.01724138, 58))
 
-  branch.expect <- c(0.175442, 0.589016, 0.589015,
-                     0.193871, 0.395144, 0.395144,
-                     0.589015, 0.475550, 0.288907,
-                     0.092767, 0.196139, 0.066625,
-                     0.129514, 0.129514, 0.196139)
   # test
   expect_equivalent(pp.obs$n.descendants, descen.expect)
-  expect_equivalent(terra::values(pp.obs$x), rast.expect)
   expect_equivalent(pp.obs$branch.length, branch.expect)
+  expect_equivalent(pp.obs$branch.length.alt, branch.alt.expect)
+
 })
 
 test_that("names in the raster and in the node path matrix
@@ -158,3 +146,4 @@ test_that("error is returned when x class is
   expect_error(phylo.pres(x, tree))
 
 })
+
